<?php
/**	
 *
 *	DOCSAWAY CLASS
 *	Author: Paul Hamlington
 *	Purpose: Talk to Docsaway via REST API. 
 * 
 */

    /** [ SET NAMESPACE: MODULIZED DOCSAWAY ] */
    namespace modulized_docsaway;
	

    /** [ DOCSAWAY CLASS ] */
    final class docsaway
        {
        
		
	    /** --------------------------> CLASS INTERFACE METHODS <--------------------------*/
		
        
	    /** [ METHOD: GET ] */
        public function mail($recipient,$PDF,$override){return($this->mailFunc($recipient,$PDF,$override));}
	    public function account(){return($this->accountFunc());}

        
	    /** --------------------------> CLASS FUNCTIONALITY METHODS <--------------------------*/
		
				
	    /** [ METHOD: CONSTRUCTOR ] */
	    public function __construct(){}
                   
        /** [ METHOD: IMPORT CLASS ] */	
        private function importClass($class)
            {
            /** [ CLASS SELECTION ] */
            switch($class)
                {
                /** [ IMPORTED OBJECTS ] */
                case 1: return(new whmcs());
                case 2: return(new license());
                }
            }
            
        /** [ METHOD: CONFIG FILE ] */    
        private function configFile()
            {           
            /** [ OBJECT: WHMCS ] */
            $obj=$this->importClass(1);
            $file=$obj->loadSettings('config');
            unset($obj);
            
            /** [ ERROR: FILE NOT FOUND ] */
            if($file===false){unset($file); return(false);}
            
            /** [ RETURN: SETTINGS ] */
            return($file);
            }        
        
        /** [ METHOD: ACCOUNT ] */     
        private function accountFunc()
            {
            /** [ METHOD: CONFIGURATION FILE ] */
            if(($file=$this->configFile())===false){unset($file); return(false);}
            
            /** [ REST: URL ] */
            $url='www.docsaway.com/app/api/rest/account.json';
            
            /** [ CREATE: MULTI-DIMENSIONAL ARRAY FOR JSON CONVERSION ] */
            $arr['APIConnection']['email']=$file['email'];
            $arr['APIConnection']['key']=$file['key'];
            $arr['balance']=true;
            $arr['volume']=true;
            $arr['reference']=true;
            $arr['company']=true;
            $arr['name']=true;
            $arr['APIReport']=false;
            unset($file);
            
            /** [ METHOD: CURL ] */
            if(($file=$this->curlFunc('https://'.$url,$arr))===false){unset($file,$arr,$url); return(false);}
                
            /** [ ERROR: API ACCOUNT NOT SET ] */
            if(empty($file)){debugger::err('Docsaway API Account returned empty results',__FILE__,__CLASS__,__METHOD__,__LINE__);  unset($file,$arr,$url); return(false);}
            
            /** [ RETURN: BOOLEAN ] */
            if($file['APIErrorNumber']!=0){debugger::err('Docsaway API Account connection failure ( error code: '.$file['APIErrorNumber'].' )',__FILE__,__CLASS__,__METHOD__,__LINE__);  unset($file,$arr,$url); return(false);}

            /** [ RETURN: ACCOUNT SETTINGS ] */
            unset($arr,$url); return($file);
            }
           
        /** [ METHOD: MAIL ] */    
        private function mailFunc($recipient,$PDF,$override)
            {
            /** [ METHOD: CONFIGURATION FILE ] */
            $file=$this->configFile();

            /** [ REST: URL ] */
            $url='www.docsaway.com/app/api/rest/mail.json';            
            
            /** [ METHOD: LICENSE ] */
            if(($error=$this->license(@$file['license']))!==true){return(array('status'=>false,'errno'=>'LC001','description'=>$error['description'],'code'=>$error['code']));} unset($error);
            
            /** [ ERROR: OVERRIDE TO BOOLEAN ] */
            if(empty($override)){$override=false;}
            
            /** [ OVERRIDE: CONFIG FILE SETTINGS ] */
            if($override!==false){foreach($override as $k => $v){if(!empty($v)){$file[$k]=$v;}}}

            /** [ CREATE: MULTI-DIMENSIONAL ARRAY FOR JSON CONVERSION ] */
            $arr['APIConnection']['email']=@$file['email'];
            $arr['APIConnection']['key']=@$file['key'];
            $arr['APIMode']=@$file['mode'];
            $arr['Recipient']['name']=$recipient['name'];
            $arr['Recipient']['company']=$recipient['company'];
            $arr['Recipient']['address1']=$recipient['address1'];
            $arr['Recipient']['address2']=$recipient['address2'];
            $arr['Recipient']['city']=$recipient['city'];
            $arr['Recipient']['state']=$recipient['state'];
            $arr['Recipient']['zip']=$recipient['postcode'];
            $arr['Recipient']['country']=$recipient['country'];
            $arr['PrintingStation']['id']='AUTO';
            $arr['PrintingStation']['courierID']=false;
            $arr['PrintingStation']['ink']=@$file['ink'];
            $arr['PrintingStation']['paper']=@$file['paper'];
            $arr['PDFFile']=base64_encode($PDF);
            $arr['APIReport']=false;
            unset($PDF,$file);

            /** [ METHOD: CURL ] */
            if(($file=$this->curlFunc('https://'.$url,$arr))===false){unset($file,$arr,$url); return(false);}
            
            /** [ ERROR: API ACCOUNT NOT SET ] */
            if(empty($file)){debugger::err('Docsaway API Mail returned empty results',__FILE__,__CLASS__,__METHOD__,__LINE__);  unset($file,$arr,$url); return(array('status'=>false,'errno'=>'040'));}
            
            /** [ RETURN: BOOLEAN ] */
            if($file['APIErrorNumber']!=0)
                {
                /** [ METHOD: DEBUGGER ] */
                debugger::err('Docsaway API Mail failure ( error code: '.$file['APIErrorNumber'].' )',__FILE__,__CLASS__,__METHOD__,__LINE__); 
                
                /** [ RETURN: RESULTS ] */
                unset($arr,$url); return(array('status'=>false,'errno'=>$file['APIErrorNumber']));
                }

            /** [ RETURN: RESULTS ] */
            unset($arr,$url); $file['status']=true; return($file);
            }
            
        /** [ METHOD: CURL ] */    
        private function curlFunc($url,$json)
            {
            /** [ CONVERT: ARRAY TO JSON FORMAT ] */
            $json=json_encode($json);
            
            /** [ OBJECT: CURL ] */
            $ch = curl_init($url);
            curl_setopt($ch,CURLOPT_RETURNTRANSFER,true);
            curl_setopt($ch,CURLOPT_CONNECTTIMEOUT,10);
            curl_setopt($ch,CURLOPT_TIMEOUT,45);
            curl_setopt($ch,CURLOPT_POST,true);
            curl_setopt($ch,CURLOPT_HTTPHEADER,array('Content-type: application/json'));
            curl_setopt($ch,CURLOPT_POSTFIELDS,$json); 
            curl_setopt($ch,CURLOPT_SSL_VERIFYPEER,false);
            curl_setopt($ch,CURLOPT_SSL_VERIFYHOST,false);                   
            curl_setopt($ch,CURLOPT_FAILONERROR,true);
            $file=curl_exec($ch);

            /** [ CATCH ALL: CURL ERRORS ] */
            if(curl_errno($ch)>0){debugger::err('Docsaway API CURL connection failure ( error code: '.curl_error($ch).' )',__FILE__,__CLASS__,__METHOD__,__LINE__); curl_close($ch); unset($file,$ch); return(false);}
              
            /** [ CLOSE: CURL OBJECT ] */
            curl_close($ch); unset($ch);
            
            /** [ CONVERT: RESPONSE JSON OBJECT TO ARRAY ] */
            $file=json_decode($file,true);            
            
            /** [ RETURN: FILE ] */
            return($file);
            }
            
        /** [ METHOD: LICENSE ] */          
        private function license($license)
            {
            /** [ OBJECT: LICENSE ] */
            $obj = $this->importClass(2);
            $obj->setLicense($license);
            $obj->setSecretKey(globals::LICENSE_KEY);
            $obj->setKeySettings(globals::LICENSE_CHECKDAYS,globals::LICENSE_FAILDAYS);
            $obj->setURL(globals::LICENSE_URL);
            $obj->execute();
            $error=$obj->getError();
            unset($obj);

            /** [ RETURN: ERROR ] */
            if($error['code']>0){return($error);}

            /** [ RETURN: BOOLEAN ] */
            unset($error); return(true);
            }            
	    }
?>