<?php
/**	
 *
 *	PDF CERTIFICATE CLASS
 *	Author: Paul Hamlington
 *	Purpose: Control all communication with TCPDF. 
 * 
 */

    /** [ SET NAMESPACE: MODULIZED DOCSAWAY ] */
    namespace modulized_docsaway;
	

    /** [ PDF CERTIFICATE CLASS ] */
    final class pdf_certificate
        {
	    /** [ PRIVATE CLASS PROPERTIES ] */
	    private $globals;
        
		
	    /** --------------------------> CLASS INTERFACE METHODS <--------------------------*/
		
        
        /** [ METHOD: EXECUTE ] */
        public function setClientID($str){$this->globals['clientID']=$str;}
        
        /** [ METHOD: EXECUTE ] */
        public function execute(){return($this->executeFunc());}
        
        /** [ METHOD: GET PDF ] */
        public function getPDF(){return($this->getPDFFunc());}
        public function getPDFDownload(){return($this->getPDFDownloadFunc());} 

        
	    /** --------------------------> CLASS FUNCTIONALITY METHODS <--------------------------*/
		
		      
	    /** [ METHOD: CONSTRUCTOR ] */
	    public function __construct()
            {
            /** [ DEFAULT: SETTING ] */
            $this->globals['orientation']  ='P';   /* [ Portrait ] */
            $this->globals['unit']         ='mm';  /* [ Millimeter ] */
            $this->globals['format']       ='A4';  /* [ A4 Papersize ] */
            $this->globals['unicode']      =true;  /* [ Character Encoding ] */
            $this->globals['encoding']     ='UTF-8'; /* [ Character Encoding ] */
            $this->globals['diskcache']    =false; /* [ Caching temporary data on filesystem ] */
            $this->globals['pdfa']         =false; /* [ PDF/A mode ] */
            $this->globals['html']         =false;
            $this->globals['pdf']          =false;
            $this->globals['clientID']     =false;
            $this->globals['sender']       =false;
            $this->globals['recipient']    =false;
            $this->globals['verification'] =false;
            
            /** [ RETURN: BOOLEAN ] */
            return(true);
            }
            
        /** [ METHOD: IMPORT CLASS ] */	
        private function importClass($class)
            {
            /** [ CLASS SELECTION ] */
            switch($class)
                {
                /** [ IMPORTED OBJECTS ] */
                case 1: return(new \TCPDF($this->globals['orientation'],$this->globals['unit'],$this->globals['format'],$this->globals['unicode'],$this->globals['encoding'],$this->globals['diskcache'],$this->globals['pdfa']));
                case 2: return(new templates());
                case 3: return(new whmcs());
                }
            }
            
        /** [ METHOD: EXECUTE ] */    
        private function executeFunc()
            {     
            /** [ ERROR: CLIENT ID NOT SET ] */
            if(empty($this->globals['clientID']))
                {
                /** [ METHOD: DEBUGGER ] */
                debugger::err('client id property not set',__FILE__,__CLASS__,__METHOD__,__LINE__);
                    
                /** [ METHOD: ALERT ] */                
                globals::alert(globals::$lang['alert']['certificate']['m2'],2,array('id'=>'property not set')); 
                
                /** [ RETURN: BOOLEAN ] */
                return(false);
                }
                         
            /** [ METHOD: CONFIGURATION ] */
            if($this->configuration()===false){return(false);} 
            
            /** [ METHOD: RECIPIENT DETAILS ] */
            if($this->recipientDetails()===false){return(false);}
            
            /** [ METHOD: CLIENT VERIFICATION ] */
            if($this->clientVerification()===false){return(false);}            
            
            /** [ METHOD: HTML STRUCTURE ] */
            $this->htmlStructure();
            
            /** [ METHOD: CREATE PDF ] */
            $this->createPDF();
            
            /** [ RETURN: BOOLEAN ] */
            return(true);
            } 
            
        /** [ METHOD: CONFIGURATION ] */    
        private function configuration()
            {
            /** [ OBJECT: WHMCS ] */
            $obj = $this->importClass(3);
            $file=$obj->getConfiguration();
            unset($obj);
            
            /** [ STORE: DETAILS ] */
            $this->globals['sender']['company'] =$file['companyname'];
            $this->globals['sender']['logo']    =$file['logourl'];
            $this->globals['sender']['address'] =(!empty($file['invoicepayto']) ?  preg_replace("/(\n|\r)+/",'<br/>',$file['invoicepayto']) : '');
           
            /** [ IMAGE: REQUIRED ] */
            if(!empty($this->globals['sender']['logo']))
                {
                /** [ ERROR: IMAGE FAILED TO LOAD ] */
                if(@getimagesize($this->globals['sender']['logo'])===false)
                    {
                    /** [ METHOD: DEBUGGER ] */
                    debugger::err('logo image failed to load('.$this->globals['sender']['logo'].')',__FILE__,__CLASS__,__METHOD__,__LINE__);
                    
                    /** [ RETURN: BOOLEAN ] */
                    unset($file); return(false);
                    }
                }
            
            /** [ RETURN: BOOLEAN ] */
            unset($file); return(true);
            }
                   
        /** [ METHOD: RECIPIENT DETAILS ] */
        private function recipientDetails()
            {
            /** [ OBJECT: WHMCS ] */
            $obj = $this->importClass(3);            
            $file=$obj->findDetails($this->globals['clientID']);
            unset($obj);
                   
            /** [ ERROR: FILE NOT FOUND ] */
            if($file===false)
                {
                /** [ METHOD: DEBUGGER ] */
                debugger::err('client details not found ( clientID: '.$this->globals['clientID'].')',__FILE__,__CLASS__,__METHOD__,__LINE__);
                    
                /** [ METHOD: ALERT ] */                
                globals::alert(globals::$lang['alert']['certificate']['m1'],2,array('id'=>$this->globals['clientID'])); 
                
                /** [ RETURN: BOOLEAN ] */
                unset($file); return(false);
                }
            
            /** [ STORE: RECIPIENT DETAILS ] */
            $this->globals['recipient']['name']     = html_entity_decode($file['firstname'].' '.$file['lastname']);
            $this->globals['recipient']['company']  = html_entity_decode($file['companyname']);
            $this->globals['recipient']['address1'] = html_entity_decode($file['address1']);
            $this->globals['recipient']['address2'] = html_entity_decode($file['address2']);
            $this->globals['recipient']['city']     = html_entity_decode($file['city']);
            $this->globals['recipient']['state']    = html_entity_decode($file['state']);
            $this->globals['recipient']['postcode'] = html_entity_decode($file['postcode']);
            $this->globals['recipient']['country']  = html_entity_decode($file['countrycode']);      
                 
            /** [ RETURN: BOOLEAN ] */ 
            unset($file); return(true); 
            }
            
        /** [ METHOD: CLIENT VERIFICATION ] */
        private function clientVerification()
            {
            /** [ OBJECT: WHMCS ] */
            $obj = $this->importClass(3);   
            $file=$obj->clientVerification($this->globals['clientID']);
            unset($obj);
                   
            /** [ ERROR: FILE NOT FOUND ] */
            if($file===false)
                {
                /** [ METHOD: DEBUGGER ] */
                debugger::err('client verification details not found ( clientID: '.$this->globals['clientID'].')',__FILE__,__CLASS__,__METHOD__,__LINE__);
                    
                /** [ METHOD: ALERT ] */                
                globals::alert(globals::$lang['alert']['certificate']['m1'],2,array('id'=>$this->globals['clientID'])); 
                
                /** [ RETURN: BOOLEAN ] */
                unset($file); return(false);
                }
            
            /** [ STORE: VERIFICATION DETAILS ] */
            $this->globals['verification']['requested_date'] = $file['requested_date'];
            $this->globals['verification']['completed_date'] = $file['completed_date'];
            $this->globals['verification']['status']         = $file['status'];
            $this->globals['verification']['reference']      = $file['reference'];
         
            /** [ RETURN: BOOLEAN ] */ 
            unset($file); return(true); 
            }            
                        
        /** [ METHOD: HTML STRUCTURE ] */    
        private function htmlStructure()
            {
            /** [ CONVERT: COUNTRY CODE ] */
            $this->globals['recipient']['country']=country::conv($this->globals['recipient']['country']);
            
            /** [ TEMPLATE: RECIPIENT FIELDS ] */
            $arr['fields']=array('name','company','address1','address2','city','state','postcode','country');
            
            /** [ BUILD: RECIPIENT ADDRESS ] */
            foreach($arr['fields'] as $k => $v){$arr['address'].=(!empty($this->globals['recipient'][$v]) ? $this->globals['recipient'][$v].'<br/>' : '');}
            
            /** [ LANGUAGE: SETTINGS ] */
            $tokens['lang:title']               =globals::$lang['certificate']['title'];
            $tokens['lang:recipient']           =globals::$lang['certificate']['recipient'];
            $tokens['lang:requested_date']      =globals::$lang['certificate']['requested_date'];
            $tokens['lang:status']              =globals::$lang['certificate']['status'];
            $tokens['lang:completed_date']      =globals::$lang['certificate']['completed_date'];
            $tokens['lang:reference']           =globals::$lang['certificate']['reference'];
            $tokens['lang:audit']               =globals::$lang['certificate']['audit'];
            
            /** [ VALUE: SETTINGS ] */
            $tokens['value:scompany']           =$this->globals['sender']['company'];
            $tokens['value:logo']               =$this->globals['sender']['logo'];
            $tokens['value:saddress']           =$this->globals['sender']['address'];
            $tokens['value:raddress']           =$arr['address'];
            $tokens['value:status']             =globals::$lang['verification']['status'][$this->globals['verification']['status']];
            $tokens['value:requested_date']     =globals::dateFormat('jS F Y',$this->globals['verification']['requested_date']);
            $tokens['value:completed_date']     =($this->globals['verification']['completed_date']==0) ? $tokens['value:status'] : globals::dateFormat('jS F Y',$this->globals['verification']['completed_date']);
            $tokens['value:reference']          =$this->globals['verification']['reference'];
            $tokens['value:audit_instructions'] =$this->replaceTokens(globals::$lang['certificate']['audit_instructions'],array('value:url'=>globals::DOCSAWAY_URL,'value:reference'=>$this->globals['verification']['reference']));

            /** [ TOKEN: CSS ] */
            $tokens['css:pdf_font']             = globals::PDF_FONT;
            $tokens['css:logo_display']         = (!empty($tokens['value:logo']) ? 'block' : 'none');
            $tokens['css:scompany_display']     = (!empty($tokens['value:scompany']) ? 'block' : 'none');
            $tokens['css:saddress_display']     = (!empty($tokens['value:saddress']) ? 'block' : 'none');
            
            /** [ METHOD: LOAD TEMPLATES ] */
            $this->globals['html']=$this->loadTemplate('letter_certificate',array(0=>$tokens));

            /** [ RETURN: BOOLEAN ] */
            unset($tokens,$arr); return(true);
            }
            
        /** [ METHOD: CREATE PDF ] */    
        private function createPDF()
            {
            /** [ OBJECT: TCPDF ] */
            $obj=$this->importClass(1);
            
            /** [ SET: HEADER|FOOTER ] */
            $obj->setPrintHeader(false);
            $obj->setPrintFooter(false);
            
            /** [ SET: MARGINS: LEFT|TOP|RIGHT ] */
            $obj->SetMargins(20,10,20,true);
            
            /** [ SET: AUTO PAGE BREAKS ] */
            $obj->SetAutoPageBreak(true);
            
            /** [ SET:FONT ] */
            $obj->SetDefaultMonospacedFont(globals::PDF_FONT);
            $obj->setFontSubsetting(true);
            $obj->SetFont(globals::PDF_FONT,'',12);

            /** [ ADD: PAGE ] */
            $obj->AddPage();
            
            /** [ OUTPUT: HTML CONTENT ] */
            $obj->writeHTML($this->globals['html'],true,false,true,false,'');    

            /** [ METHOD: LAST PAGE ] */
            $obj->lastPage();
            
            /** [ OUTPUT: PDF ] */
            $this->globals['pdf']=$obj->Output('','S');
            
            /** [ RETURN: BOOLEAN ] */
            unset($obj); return(true);
            }

        /** [ METHOD: LOAD TEMPLATE ] */
        private function loadTemplate($filename,$tokens)
            {
            /** [ OBJECT: TEMPLATES ] */
            $obj=$this->importClass(2);
            $obj->setFileName($filename);
            $obj->setTokens($tokens);
            $xhtml=$obj->getTemplate();
            
            /** [ RETURN: XHTML ] */
            unset($obj); return($xhtml);
            }   
            
        /** [ METHOD: REPLACE TOKENS ] */
        private function replaceTokens($text,$tokens)
            {
            /** [ OBJECT: TEMPLATES ] */
            $obj=$this->importClass(2);
            $text=$obj->replaceTokens($text,$tokens);

            /** [ RETURN: XHTML ] */
            unset($obj); return($text);
            }              
            
        /** [ METHOD: GET PDF ] */    
        private function getPDFFunc()
            {
            /** [ RETURN: BOOLEAN ] */
            if(empty($this->globals['pdf'])){return(false);}
            
            /** [ RETURN: PDF ] */
            return($this->globals['pdf']);
            }            
            
        /** [ METHOD: GET PDF ] */    
        private function getPDFDownloadFunc()
            {
            /** [ DOWNLOAD: THROUGH BROWSER ] */
            header("Pragma: public");
            header('Content-type: application/pdf');
            header('Content-Disposition: attachment; filename="certificate_'.$this->globals['clientID'].'.pdf"');            
            echo($this->globals['pdf']); exit; 
            }             
	    }
?>