<?php
/**	
 * 
 *	ADMIN: ACTION CONFIGURATION CLASS
 *	Author: Paul Hamlington
 *	Purpose: Wrap the configuration action code.
 *
 */

    /** [ SET NAMESPACE: MODULIZED DOCSAWAY ] */
    namespace modulized_docsaway;	
	

    /** [ ADMIN: ACTION CONFIGURATION CLASS ] */
    final class a_action_configuration
        {
	    /** [ PRIVATE CLASS PROPERTIES ] */
	    private $globals;
			
                
	    /** --------------------------> CLASS INTERFACE METHODS <--------------------------*/
		
		
        /** [ METHOD: SET ] */
        public function setPassword($string){$this->globals['pw']=$string;}
        public function setFields($arr){$this->setFieldsFunc($arr);}
            
	    /** [ METHOD: EXECUTE ] */
	    public function execute(){$this->executeFunc();}
		
		
	    /** --------------------------> CLASS FUNCTIONALITY METHODS <--------------------------*/
		
				
	    /** [ METHOD: CONSTRUCTOR ] */
	    public function __construct()
            {
            /** [ DEFAULT: GLOBALS ] */
            $this->globals = 
                array('pw'                => '',
                      'license'           => '',
                      'email'             => '',
                      'key'               => '',
                      'ccField'           => '',
                      'mode'              => '',
                      'ink'               => '',
                      'paper'             => '',
                      'notificationEmail' => '',
                      'timeFrame'         => '',
                      'product'           => '',
                      'domainName'        => '',
                      'letterContent'     => '',
                      'homeHook'          => '',
                      'clientHook'        => '');
            
            /** [ RETURN: BOOLEAN ] */
            return(true);            
            }
                    
        /** [ METHOD: IMPORT CLASS ] */	
        private function importClass($class)
            {
            /** [ CLASS SELECTION ] */
            switch($class)
                {
                /** [ IMPORTED OBJECTS ] */
                case 1: return(new license());
                case 3: return(new whmcs());
                }
            }	
       
        /** [ METHOD: SET FIELDS ] */    
        private function setFieldsFunc($arr)
            {
            /** [ VALIDATE: POST FIELDS ] */
            validation::mandatory($arr['license'],30,globals::$lang['configuration']['r11'],2);
            validation::email($arr['email'],150,globals::$lang['configuration']['r1'],2);
            validation::mandatory($arr['key'],64,globals::$lang['configuration']['r2'],2);            
            validation::mandatory($arr['mode'],4,globals::$lang['configuration']['r4'],2);
            validation::mandatory($arr['ink'],2,globals::$lang['configuration']['r5'],2);
            validation::mandatory($arr['paper'],3,globals::$lang['configuration']['r6'],2);
            validation::email($arr['notificationEmail'],150,globals::$lang['configuration']['r7'],2);
            validation::numeric($arr['timeFrame'],2,globals::$lang['configuration']['r8'],2);
            validation::numeric($arr['homeHook'],1,globals::$lang['configuration']['r12'],2);
            validation::numeric($arr['clientHook'],1,globals::$lang['configuration']['r13'],2);
            
            /** [ STORE: POST FIELDS ] */
            $this->globals['license']           =$arr['license'];
            $this->globals['email']             =$arr['email'];
            $this->globals['key']               =$arr['key'];
            $this->globals['mode']              =$arr['mode'];
            $this->globals['ink']               =$arr['ink'];
            $this->globals['paper']             =$arr['paper'];
            $this->globals['notificationEmail'] =$arr['notificationEmail'];
            $this->globals['timeFrame']         =$arr['timeFrame'];
            $this->globals['product']           =$arr['product'];
            $this->globals['domainName']        =$arr['domainName'];
            $this->globals['letterContent']     =$arr['letterContent'];            
            $this->globals['homeHook']          =$arr['homeHook'];
            $this->globals['clientHook']        =$arr['clientHook'];
            
            /** [ RETURN: BOOLEAN ] */
            unset($arr); return(true);
            }            
            
        /** [ METHOD: EXECUTE ] */		
	    private function executeFunc()
            {
            /** [ ERROR: ALERT DETECTED ] */
            if(!empty(globals::$alert)){return(false);}
            
            /** [ ERROR: PASSWORD MISMATCH ] */
            if($this->globals['pw']!==md5(globals::FORM_PASSWORD))
                {
                /** [ METHOD: DEBUGGER ] */
                debugger::err('Access denied, password mismatch detected',__FILE__,__CLASS__,__METHOD__,__LINE__);
                
                /** [ METHOD: ALERT ] */
                globals::alert(globals::$lang['alert']['configuration']['m1'],2,false);
                   
                /** [ RETURN: BOOLEAN ] */
                return(false);
                }
            
            /** [ METHOD: SAVE ] */
            $this->save();
             
            /** [ METHOD: SAVE LETTER CONTENT ] */
            $this->saveLetterContent();
            
            /** [ METHOD: LICENSE DELETE KEY ] */
            $this->licenseDelKey();
            
            /** [ STORE: MESSAGE ] */
            globals::alert(globals::$lang['alert']['configuration']['m2'],1,false);

            /** [ RETURN: BOOLEAN ] */
            return(true);
            }
 
        /** [ METHOD: SAVE ] */    
        private function save()
            {
            /** [ STORE: FILE ] */
            $file['license']           =$this->globals['license'];
            $file['email']             =$this->globals['email'];
            $file['key']               =$this->globals['key'];
            $file['mode']              =$this->globals['mode'];
            $file['ink']               =$this->globals['ink'];
            $file['paper']             =$this->globals['paper'];
            $file['notificationEmail'] =$this->globals['notificationEmail'];
            $file['timeFrame']         =$this->globals['timeFrame'];
            $file['product']           =$this->product();
            $file['domainName']        =$this->domainName();
            $file['homeHook']          =$this->globals['homeHook'];
            $file['clientHook']        =$this->globals['clientHook'];
            
            /** [ ERROR: CUSTOM FIELD NOT CREATED ] */
            if(($file['ccField']=$this->customField(1,false))===false){globals::alert(globals::$lang['alert']['configuration']['m4'],2,false); unset($file); return(false);}
            
            /** [ OBJECT: WHMCS ] */
            $obj=$this->importClass(3);           
            $save=$obj->saveSettings('config',$file);
            unset($obj);  

            /** [ RETURN: BOOLEAN ] */
            if($save===true){unset($file,$save); return(true);}

            /** [ METHOD: ALERT ] */
            globals::alert(globals::$lang['alert']['configuration']['m1'],2,false);
            
            /** [ METHOD: CUSTOM FIELD ] */
            $this->customField(2,$file['ccField']); 
            
            /** [ RETURN: BOOLEAN ] */
            unset($save,$file); return(false);
            }
            
        /** [ METHOD: CUSTOM FIELD ] */     
        private function customField($action,$id)
            {           
            /** [ OBJECT: WHMCS ] */
            $obj=$this->importClass(3);            
            
            /** [ ACTION: SELECTION ] */
            switch($action)
                {
                /** [ CREATE: CUSTOM FIELD ] */
                case 1: $id=$obj->createCustomField(); unset($obj); return($id);
                               
                /** [ DELETE: CUSTOM FIELD ] */
                case 2: $obj->deleteCustomField($id); break;              
                }
                            
            /** [ RETURN: BOOLEAN ] */    
            unset($obj); return(true);    
            }
            
        /** [ METHOD: PRODUCT ] */    
        private function product()
            {
            /** [ OBJECT: WHMCS ] */
            $obj=$this->importClass(3);
            $file=$obj->getProducts();
            unset($obj);
            
            /** [ ERROR: PRODUCTS EMPTY ] */
            if($file===false){unset($file); return(false);}
            
            /** [ FLIP: ARRAY ] */
            $arr=array_flip($this->globals['product']); 
            
            /** [ REMOVE: NONE SETTING ] */
            if(isset($arr[0])){unset($arr[0]);}

            /** [ BUILD: PRODUCT ARRAY ] */
            foreach($arr as $k => $v){$product[$k]=$file[$k];}
            
            /** [ RETURN: PRODUCT ] */
            unset($file,$arr); return($product);
            }
            
        /** [ METHOD: DOMAIN NAME ] */    
        private function domainName()
            {
            /** [ OBJECT: WHMCS ] */
            $obj=$this->importClass(3);
            $file=$obj->getDomainPricing();
            unset($obj);
            
            /** [ ERROR: DOMAIN NAMES EMPTY ] */
            if($file===false){unset($file); return(false);}

            /** [ FLIP: ARRAY ] */
            $arr=array_flip($this->globals['domainName']); 
            
            /** [ REMOVE: NONE SETTING ] */
            if(isset($arr[0])){unset($arr[0]);}            

            /** [ BUILD: DOMAIN NAME ARRAY ] */
            foreach($arr as $k => $v){$domain[$k]=$file[$k];} 
            
            /** [ RETURN: DOMAINS ] */
            unset($file,$arr); return($domain);
            }
            
        /** [ METHOD: SAVE LETTER CONTENT ] */    
        private function saveLetterContent()
            {
            /** [ ERROR: LETTER CONTENT EMPTY ] */
            if(empty($this->globals['letterContent'])){return(false);}
            
            /** [ REPLACE: BREAKS ] */
            $file=str_ireplace("\n",'<br/>',$this->globals['letterContent']);
            
            /** [ OBJECT: WHMCS ] */
            $obj=$this->importClass(3);           
            $save=$obj->saveSettings('verification_letter',$file);
            unset($obj);             
                        
            /** [ ERROR: FILE NOT SAVED ] */
            if($save===false){globals::alert(globals::$lang['alert']['configuration']['m3'],2,false); unset($save,$file); return(false);}
            
            /** [ RETURN: BOOLEAN ] */
            unset($save,$file); return(true);
            }
            
        /** [ METHOD: LICENSE DELETE KEY ] */    
        private function licenseDelKey()
            {
            /** [ OBJECT: LICENSE ] */
            $obj = $this->importClass(1);
            $obj->delLocalKey();
            unset($obj);
            
            /** [ RETURN: BOOLEAN ] */
            return(true);
            }            
        }
?>