<?php
/**	
 * 
 *	ADMIN: ACTION INVOICES CLASS
 *	Author: Paul Hamlington
 *	Purpose: Wrap the invoices action code.
 *
 */

    /** [ SET NAMESPACE: MODULIZED DOCSAWAY ] */
    namespace modulized_docsaway;	
	

    /** [ ADMIN: ACTION INVOICES CLASS ] */
    final class a_action_invoices
        {
	    /** [ PRIVATE CLASS PROPERTIES ] */
	    private $globals;
			
                
	    /** --------------------------> CLASS INTERFACE METHODS <--------------------------*/
		
		
        /** [ METHOD: SET ] */
        public function setPassword($string){$this->globals['pw']=$string;}
        public function setInvoiceID($int){$this->globals['invoiceID']=$int;}
        public function setClientID($int){$this->globals['clientID']=$int;}
        public function setFields($arr){$this->setFieldsFunc($arr);}       
            
	    /** [ METHOD: EXECUTE ] */
	    public function execute(){$this->executeFunc();}
		
		
	    /** --------------------------> CLASS FUNCTIONALITY METHODS <--------------------------*/
		
				
	    /** [ METHOD: CONSTRUCTOR ] */
	    public function __construct()
            {
            /** [ DEFAULT: GLOBALS ] */
            $this->globals = 
                array('pw'        => '',
                      'invoiceID' => '',
                      'clientID'  => '',
                      'recipient' => array(),
                      'mode'      => '',
                      'ink'       => '',
                      'paper'     => '');
            
            /** [ RETURN: BOOLEAN ] */
            return(true);            
            }
                    
        /** [ METHOD: IMPORT CLASS ] */	
        private function importClass($class)
            {
            /** [ CLASS SELECTION ] */
            switch($class)
                {
                /** [ IMPORTED OBJECTS ] */
                case 1: return(new docsaway());
                case 2: return(new whmcs());
                }
            }
            
        /** [ METHOD: SET FIELDS ] */    
        private function setFieldsFunc($arr)
            {
            /** [ VALIDATE: POST FIELDS ] */         
            validation::mandatory($arr['mode'],4,globals::$lang['invoices']['b3_4'],2);
            validation::mandatory($arr['ink'],2,globals::$lang['invoices']['b3_1'],2);
            validation::mandatory($arr['paper'],3,globals::$lang['invoices']['b3_2'],2);

            /** [ STORE: POST FIELDS ] */
            $this->globals['mode']  =$arr['mode'];
            $this->globals['ink']   =$arr['ink'];
            $this->globals['paper'] =$arr['paper'];            
            
            /** [ RETURN: BOOLEAN ] */
            unset($arr); return(true);
            }            
         
        /** [ METHOD: EXECUTE ] */		
	    private function executeFunc()
            {
            /** [ ERROR: ALERT DETECTED ] */
            if(!empty(globals::$alert)){return(false);}
            
            /** [ ERROR: INVOICE ID NOT SET ] */
            if(!isset($this->globals['invoiceID'])){globals::alert(globals::$lang['alert']['invoice']['m1'],2,false); return(false);}
            
            /** [ ERROR: CLIENT ID NOT SET ] */
            if(!isset($this->globals['clientID'])){globals::alert(globals::$lang['alert']['invoice']['m2'],2,array('id'=>$this->globals['invoiceID'])); return(false);}
             
            /** [ ERROR: PASSWORD MISMATCH ] */
            if($this->globals['pw']!==md5(globals::FORM_PASSWORD))
                {
                /** [ METHOD: DEBUGGER ] */
                debugger::err('Access denied, password mismatch detected',__FILE__,__CLASS__,__METHOD__,__LINE__);
                
                /** [ METHOD: ALERT ] */
                globals::alert(globals::$lang['alert']['invoice']['m2'],2,array('id'=>$this->globals['invoiceID']));
                   
                /** [ RETURN: BOOLEAN ] */
                return(false);
                }
            
            /** [ METHOD: CLIENT ] */    
            if($this->client()===false){return(false);}
            
            /** [ METHOD: MAIL ] */
            if($this->mail()===false){return(false);}
                
            /** [ RETURN: BOOLEAN ] */
            return(true);
            }
            
        /** [ METHOD: CLIENT ] */
        private function client()
            {
            /** [ OBJECT: WHMCS ] */
            $obj = $this->importClass(2);
            $file=$obj->getClient($this->globals['clientID']);
            unset($obj);
            
            /** [ ERROR: FILE NOT FOUND ] */
            if($file===false){globals::alert(globals::$lang['alert']['invoice']['m2'],2,array('id'=>$this->globals['invoiceID'])); unset($file); return(false);}
            
            /** [ STORE: RECIPIENT DETAILS ] */
            $this->globals['recipient']['name']     = html_entity_decode($file['firstname'].' '.$file['lastname']);
            $this->globals['recipient']['company']  = html_entity_decode($file['companyname']);
            $this->globals['recipient']['address1'] = html_entity_decode($file['address1']);
            $this->globals['recipient']['address2'] = html_entity_decode($file['address2']);
            $this->globals['recipient']['city']     = html_entity_decode($file['city']);
            $this->globals['recipient']['state']    = html_entity_decode($file['state']);
            $this->globals['recipient']['postcode'] = html_entity_decode($file['postcode']);
            $this->globals['recipient']['country']  = html_entity_decode($file['countrycode']);      
                    
            /** [ RETURN: BOOLEAN ] */ 
            unset($file); return(true);
            }
        
        /** [ METHOD: MAIL ] */    
        private function mail()
            {
            /** [ OBJECT: WHMCS ] */
            $obj = $this->importClass(2);
            $PDF=$obj->PDFInvoice($this->globals['invoiceID']);
            unset($obj);
            
            /** [ ERROR: PDF INVOICE NOT FOUND ] */
            if($PDF===false)
                {
                /** [ METHOD: ALERT ] */
                globals::alert(globals::$lang['alert']['invoice']['m3'],2,array('id'=>$this->globals['invoiceID'])); 
                
                /** [ METHOD: LOG ACTIVITIES ] */
                globals::logActivity(globals::$lang['log']['invoice']['m8'],array('id'=>$this->globals['invoiceID']));
                
                /** [ RETURN: BOOLEAN ] */
                unset($file,$PDF); return(false);
                }
            
            /** [ OBJECT: MAIL ] */
            $obj = $this->importClass(1);
            $override=array('mode'=>$this->globals['mode'],'ink'=>$this->globals['ink'],'paper'=>$this->globals['paper']);
            $file=$obj->mail($this->globals['recipient'],$PDF,$override);
            unset($obj,$PDF,$override);
            
            /** [ ERROR: MAIL NOT SENT ] */
            if($file['status']===false)
                {
                /** [ METHOD: LOG ] */
                switch($file['errno'])
                    {
                    /** [ ERROR: CONNECTION FAILURE ] */
                    case '002': case '003': case '040': 
                        
                        /** [ METHOD: ALERT ] */
                        globals::alert(globals::$lang['alert']['invoice']['m4'],2,array('id'=>$this->globals['invoiceID'],'errno'=>$file['errno'])); 
                        
                        /** [ METHOD: LOG ACTIVITIES ] */
                        globals::logActivity(globals::$lang['log']['invoice']['m4'],array('id'=>$this->globals['invoiceID'],'errno'=>$file['errno'])); break;
                        
                    /** [ ERROR: INSUFFICIENT FUNDS ] */
                    case '032': 
                        
                        /** [ METHOD: ALERT ] */
                        globals::alert(globals::$lang['alert']['invoice']['m5'],2,array('id'=>$this->globals['invoiceID'],'errno'=>$file['errno'])); 
                        
                        /** [ METHOD: LOG ACTIVITIES ] */
                        globals::logActivity(globals::$lang['log']['invoice']['m5'],array('id'=>$this->globals['invoiceID'],'errno'=>$file['errno'])); break;
                    
                    /** [ ERROR: LICENSE FAILURE ] */
                    case 'LC001':
                        
                        /** [ METHOD: ALERT ] */
                        globals::alert(globals::$lang['alert']['license']['m1'],2,array('description'=>$file['description'],'code'=>$file['code'])); 
                        
                        /** [ METHOD: LOG ACTIVITIES ] */
                        globals::logActivity(globals::$lang['log']['license']['m1'],array('description'=>$file['description'],'code'=>$file['code'])); break;
                    
                    /** [ ERROR: CATCH ALL ] */
                    default: 
                        
                        /** [ METHOD: ALERT ] */
                        globals::alert(globals::$lang['alert']['invoice']['m6'],2,array('id'=>$this->globals['invoiceID'],'errno'=>$file['errno'])); 
                        
                        /** [ METHOD: LOG ACTIVITIES ] */
                        globals::logActivity(globals::$lang['log']['invoice']['m6'],array('id'=>$this->globals['invoiceID'],'errno'=>$file['errno'])); break;
                    }

                /** [ RETURN: BOOLEAN ] */
                unset($file); return(false);
                }
            
            /** [ METHOD ALERT ] */
            globals::alert(globals::$lang['alert']['invoice']['m7'],1,array('id'=>$this->globals['invoiceID'],'reference'=>$file['transaction']['reference']));
            
            /** [ METHOD LOG ACTIVITY ] */    
            globals::logActivity(globals::$lang['log']['invoice']['m7'],array('id'=>$this->globals['invoiceID'],'reference'=>$file['transaction']['reference']));            
            
            /** [ RETURN: BOOLEAN ] */
            unset($file); return(true);
            }
        }
?>