<?php
/**	
 * 
 *	ADMIN: ACTION LETTER CLASS
 *	Author: Paul Hamlington
 *	Purpose: Wrap the letter action code.
 *
 */

    /** [ SET NAMESPACE: MODULIZED DOCSAWAY ] */
    namespace modulized_docsaway;	
	

    /** [ ADMIN: ACTION LETTER CLASS ] */
    final class a_action_letter
        {
	    /** [ PRIVATE CLASS PROPERTIES ] */
	    private $globals;
			
                
	    /** --------------------------> CLASS INTERFACE METHODS <--------------------------*/
		
		
        /** [ METHOD: SET ] */
        public function setPassword($string){$this->globals['pw']=$string;}
        public function setClientID($str){$this->globals['clientID']=$str;}
        public function setFields($arr){$this->setFieldsFunc($arr);}       
            
	    /** [ METHOD: EXECUTE ] */
	    public function execute(){$this->executeFunc();}
		
		
	    /** --------------------------> CLASS FUNCTIONALITY METHODS <--------------------------*/
		
				
	    /** [ METHOD: CONSTRUCTOR ] */
	    public function __construct()
            {
            /** [ DEFAULT: GLOBALS ] */
            $this->globals = 
                array('pw'        => '',
                      'clientID'  => '',
                      'recipient' => array(),
                      'mode'      => '',
                      'ink'       => '',
                      'paper'     => '',
                      'content'   => '',
                      'reference' => '');
            
            /** [ RETURN: BOOLEAN ] */
            return(true);            
            }
                    
        /** [ METHOD: IMPORT CLASS ] */	
        private function importClass($class)
            {
            /** [ CLASS SELECTION ] */
            switch($class)
                {
                /** [ IMPORTED OBJECTS ] */
                case 1: return(new docsaway());
                case 2: return(new whmcs());
                case 3: return(new pdf_letter());
                }
            }
            
        /** [ METHOD: SET FIELDS ] */    
        private function setFieldsFunc($arr)
            {
            /** [ VALIDATE: POST FIELDS ] */         
            validation::mandatory($arr['mode'],4,globals::$lang['letter']['b2_4'],2);
            validation::mandatory($arr['ink'],2,globals::$lang['letter']['b2_1'],2);
            validation::mandatory($arr['paper'],3,globals::$lang['letter']['b2_2'],2);
            
            /** [ STORE: POST FIELDS ] */
            $this->globals['mode']    =$arr['mode'];
            $this->globals['ink']     =$arr['ink'];
            $this->globals['paper']   =$arr['paper'];
            $this->globals['content'] =$arr['content'];
            
            /** [ RETURN: BOOLEAN ] */
            unset($arr); return(true);
            }            
         
        /** [ METHOD: EXECUTE ] */		
	    private function executeFunc()
            {
            /** [ ERROR: ALERT DETECTED ] */
            if(!empty(globals::$alert)){return(false);}
            
            /** [ ERROR: CLIENT ID NOT SET ] */
            if(empty($this->globals['clientID'])){globals::alert(globals::$lang['alert']['letter']['m1'],2,false); return(false);}
             
            /** [ ERROR: PASSWORD MISMATCH ] */
            if($this->globals['pw']!==md5(globals::FORM_PASSWORD))
                {
                /** [ METHOD: DEBUGGER ] */
                debugger::err('Access denied, password mismatch detected',__FILE__,__CLASS__,__METHOD__,__LINE__);
                
                /** [ METHOD: ALERT ] */
                globals::alert(globals::$lang['alert']['letter']['m3'],2,array('id'=>$this->globals['clientID']));
                   
                /** [ RETURN: BOOLEAN ] */
                return(false);
                }
            
            /** [ METHOD: RECIPIENT DETAILS ] */    
            if($this->recipientDetails()===false){return(false);}
            
            /** [ METHOD: MAIL ] */
            if($this->mail()===false){return(false);}

            /** [ RETURN: BOOLEAN ] */
            return(true);
            }
            
        /** [ METHOD: RECIPIENT DETAILS ] */
        private function recipientDetails()
            {
            /** [ OBJECT: WHMCS ] */
            $obj = $this->importClass(2);            
            $file=$obj->findDetails($this->globals['clientID']);
            unset($obj);
                   
            /** [ ERROR: FILE NOT FOUND ] */
            if($file===false)
                {
                /** [ METHOD: ALERT ] */                
                globals::alert(globals::$lang['alert']['letter']['m3'],2,array('id'=>$this->globals['clientID'])); 
                
                /** [ RETURN: BOOLEAN ] */
                unset($file); return(false);
                }
            
            /** [ STORE: RECIPIENT DETAILS ] */
            $this->globals['recipient']['name']     = html_entity_decode($file['firstname'].' '.$file['lastname']);
            $this->globals['recipient']['company']  = html_entity_decode($file['companyname']);
            $this->globals['recipient']['address1'] = html_entity_decode($file['address1']);
            $this->globals['recipient']['address2'] = html_entity_decode($file['address2']);
            $this->globals['recipient']['city']     = html_entity_decode($file['city']);
            $this->globals['recipient']['state']    = html_entity_decode($file['state']);
            $this->globals['recipient']['postcode'] = html_entity_decode($file['postcode']);
            $this->globals['recipient']['country']  = html_entity_decode($file['countrycode']);      
                 
            /** [ RETURN: BOOLEAN ] */ 
            unset($file); return(true); 
            }
        
        /** [ METHOD: MAIL ] */    
        private function mail()
            {
            /** [ METHOD: PDF ] */
            if(($PDF=$this->PDF())===false){unset($PDF); return(false);}
            
            /** [ OBJECT: DOCSAWAY ] */
            $obj = $this->importClass(1);
            $override=array('mode'=>$this->globals['mode'],'ink'=>$this->globals['ink'],'paper'=>$this->globals['paper']);
            $file=$obj->mail($this->globals['recipient'],$PDF,$override);
            unset($obj,$PDF,$override);
            
            /** [ ERROR: MAIL NOT SENT ] */
            if($file['status']===false)
                {
                /** [ METHOD: LOG ] */
                switch($file['errno'])
                    {
                    /** [ ERROR: CONNECTION FAILURE ] */
                    case '002': case '003': case '040':
                        
                        /** [ METHOD: ALERT ] */
                        globals::alert(globals::$lang['alert']['letter']['m4'],2,array('id'=>$this->globals['clientID'],'errno'=>$file['errno'])); 
                        
                        /** [ METHOD: LOG ACTIVITIES ] */
                        globals::logActivity(globals::$lang['log']['letter']['m1'],array('id'=>$this->globals['clientID'],'errno'=>$file['errno'])); break;                        
                    
                    /** [ ERROR: INSUFFICIENT FUNDS ] */
                    case '032':
                        
                        /** [ METHOD: ALERT ] */
                        globals::alert(globals::$lang['alert']['letter']['m5'],2,array('id'=>$this->globals['clientID'],'errno'=>$file['errno'])); 
                        
                        /** [ METHOD: LOG ACTIVITIES ] */
                        globals::logActivity(globals::$lang['log']['letter']['m2'],array('id'=>$this->globals['clientID'],'errno'=>$file['errno'])); break;                        
                    
                    /** [ ERROR: LICENSE FAILURE ] */
                    case 'LC001':
                        
                        /** [ METHOD: ALERT ] */
                        globals::alert(globals::$lang['alert']['license']['m1'],2,array('description'=>$file['description'],'code'=>$file['code'])); 
                        
                        /** [ METHOD: LOG ACTIVITIES ] */
                        globals::logActivity(globals::$lang['log']['license']['m1'],array('description'=>$file['description'],'code'=>$file['code'])); break;
                                        
                    /** [ ERROR: CATCH ALL ] */
                    default: 
                        
                        /** [ METHOD: ALERT ] */
                        globals::alert(globals::$lang['alert']['letter']['m6'],2,array('id'=>$this->globals['clientID'],'errno'=>$file['errno'])); 
                        
                        /** [ METHOD: LOG ACTIVITIES ] */
                        globals::logActivity(globals::$lang['log']['letter']['m4'],array('id'=>$this->globals['clientID'],'errno'=>$file['errno'])); break;                        
                    }

                /** [ RETURN: BOOLEAN ] */
                unset($file); return(false);
                }
                
            /** [ STORE: REFERENCE ] */    
            $this->globals['reference']=$file['transaction']['reference'];
                
            /** [ METHOD ALERT ] */
            globals::alert(globals::$lang['alert']['letter']['m7'],1,array('id'=>$this->globals['clientID'],'reference'=>$this->globals['reference']));
            
            /** [ METHOD LOG ACTIVITY ] */    
            globals::logActivity(globals::$lang['log']['letter']['m3'],array('id'=>$this->globals['clientID'],'reference'=>$this->globals['reference'])); 
            
            /** [ RETURN: BOOLEAN ] */
            unset($file); return(true);           
            }
   
        /** [ METHOD: PDF ] */
        private function PDF()
            {
            /** [ OBJECT: PDF LETTER ] */
            $obj=$this->importClass(3);
            $obj->setRecipient($this->globals['recipient']);
            $obj->setContent($this->globals['content']);
            $obj->execute();
            $pdf=$obj->getPDF();
            unset($obj);
            
            /** [ ERROR: PDF NOT CREATED ] */
            if($pdf===false){unset($pdf); return(false);}
            
            /** [ RETURN: PDF ] */
            return($pdf);
            }            
        }
?>