<?php
/**	
 * 
 *	CLIENT: ACTION VERIFICATION CLASS
 *	Author: Paul Hamlington
 *	Purpose: Wrap the verification action code.
 *
 */

    /** [ SET NAMESPACE: MODULIZED DOCSAWAY ] */
    namespace modulized_docsaway;	
	

    /** [ CLIENT: ACTION VERIFICATION CLASS ] */
    final class c_action_verification
        {
	    /** [ PRIVATE CLASS PROPERTIES ] */
	    private $globals;
			
                
	    /** --------------------------> CLASS INTERFACE METHODS <--------------------------*/
		
		
        /** [ METHOD: SET ] */
        public function setPassword($string){$this->globals['pw']=$string;}
        public function setFields($arr){$this->setFieldsFunc($arr);}
            
	    /** [ METHOD: EXECUTE ] */
	    public function execute(){$this->executeFunc();}
		
		
	    /** --------------------------> CLASS FUNCTIONALITY METHODS <--------------------------*/
		
				
	    /** [ METHOD: CONSTRUCTOR ] */
	    public function __construct()
            {
            /** [ DEFAULT: GLOBALS ] */
            $this->globals = 
                array('pw'            => '',
                      'to'            => '',
                      'from'          => '',
                      'clientID'      => '',
                      'name'          => '',
                      'requestedDate' => '',
                      'dueDate'       => '',
                      'completedDate' => '',
                      'status'        => '',
                      'code'          => '');
            
            /** [ RETURN: BOOLEAN ] */
            return(true);            
            }
                    
        /** [ METHOD: IMPORT CLASS ] */	
        private function importClass($class)
            {
            /** [ CLASS SELECTION ] */
            switch($class)
                {
                /** [ IMPORTED OBJECTS ] */
                case 1: return(new whmcs());
                case 3: return(new templates());
                }
            }	
       
        /** [ METHOD: SET FIELDS ] */    
        private function setFieldsFunc($arr)
            {
            /** [ VALIDATE: POST FIELDS ] */
            validation::mandatory($arr['clientID'],20,'Choose Client',4);
            validation::mandatory($arr['code'],6,'Code',4); 
            
            /** [ STORE: POST FIELDS ] */
            $this->globals['clientID'] =$arr['clientID'];
            $this->globals['code'] =$arr['code'];          
            
            /** [ RETURN: BOOLEAN ] */
            unset($arr); return(true);
            }            
            
        /** [ METHOD: EXECUTE ] */		
	    private function executeFunc()
            {
            /** [ ERROR: ALERT DETECTED ] */
            if(!empty(globals::$alert)){return(false);}
            
            /** [ ERROR: PASSWORD MISMATCH ] */
            if($this->globals['pw']!==md5(globals::FORM_PASSWORD))
                {
                /** [ METHOD: DEBUGGER ] */
                debugger::err('Access denied, password mismatch detected',__FILE__,__CLASS__,__METHOD__,__LINE__);
                
                /** [ METHOD: ALERT ] */
                globals::alert(globals::$lang['alert']['verification']['c_m1'],4,false);
                   
                /** [ RETURN: BOOLEAN ] */
                return(false);
                }
            
            /** [ METHOD: CONFIG FILE ] */
            $this->configFile();    
                
            /** [ METHOD: WHMCS CONFIGURATION ] */
            $this->WHMCSConfiguration();
            
            /** [ METHOD: VERIFY ] */
            if($this->verify()===false){return(false);}
                         
            /** [ METHOD: EMAIL ] */
            $this->email();
            
            /** [ STORE: MESSAGE ] */
            globals::alert(globals::$lang['alert']['verification']['c_m3'],3,false);

            /** [ RETURN: BOOLEAN ] */
            return(true);
            }
            
        /** [ METHOD: CONFIG FILE ] */    
        private function configFile()
            {
            /** [ OBJECT: WHMCS ] */
            $obj=$this->importClass(1);
            $file=$obj->loadSettings('config');
            unset($obj);
            
            /** [ ERROR: FILE NOT FOUND ] */
            if($file===false){debugger::err('Config file not found',__FILE__,__CLASS__,__METHOD__,__LINE__); unset($file); return(false);}
            
            /** [ STORE: EMAIL ] */
            $this->globals['to']=$file['email'];

            /** [ RETURN: BOOLEAN ] */
            unset($file); return(true);
            }       
            
        /** [ METHOD: WHMCS CONFIGURATION ] */    
        private function WHMCSConfiguration()
            {
            /** [ OBJECT: WHMCS ] */
            $obj=$this->importClass(1);
            $file=$obj->getConfiguration();
            unset($obj);            

            /** [ STORE: EMAIL ] */
            $this->globals['from']=$file['email'];            
    
            /** [ RETURN: BOOLEAN ] */
            unset($file); return(true);
            }            
            
        /** [ METHOD: VERIFY ] */    
        private function verify()
            {
            /** [ METHOD: CLIENT VERIFICATION ] */
            if(($file=$this->clientVerification())===false){return(false);}
            
            /** [ STATUS: SELECTION ] */
            switch($file['status'])
                {
                /** [ STATUS: VERIFIED ] */
                case 1: globals::alert(globals::$lang['alert']['verification']['c_m4'],3,false); unset($file); return(false);
                    
                /** [ STATUS: FAILED VERIFICATION ] */
                case 3: globals::alert(globals::$lang['alert']['verification']['c_m5'],4,false); unset($file); return(false);
                }
            
            /** [ ERROR: CODE MISMATCH ] */
            if($file['code']!==$this->globals['code']){globals::alert(globals::$lang['alert']['verification']['c_m2'],4,false); unset($file); return(false);}

            /** [ METHOD: CLIENT VERIFICATION UPDATE ] */
            if($this->clientVerificationUpdate()===false){globals::alert(globals::$lang['alert']['verification']['c_m1'],4,false); unset($file); return(false);}
            
            /** [ METHOD: CLIENT VERIFICATION ] */
            if(($file=$this->clientVerification())===false){return(false);}
            
            /** [ STORE: DETAILS ] */
            $this->globals['name']          = $file['name'];
            $this->globals['requestedDate'] = $file['requested_date'];
            $this->globals['dueDate']       = $file['due_date'];
            $this->globals['completedDate'] = $file['completed_date'];
            $this->globals['status']        = $file['status'];  
            
            /** [ RETURN: BOOLEAN ] */
            unset($file); return(true);
            }
            
        /** [ METHOD: EMAIL ] */
        private function email()
            {
            /** [ METHOD: CLIENTID ] */
            $file=globals::clientID($this->globals['clientID'],false,'decode');
               
            /** [ VALUE: TOKENS ] */
            $tokens['value:id']             =(($file['type']==0) ? globals::$lang['email']['clientID'] : globals::$lang['email']['contactID']).': '.$file['id'];
            $tokens['value:name']           =$this->globals['name'];
            $tokens['value:requested_date'] =globals::dateFormat('jS F Y',$this->globals['requestedDate']);
            $tokens['value:due_date']       =globals::dateFormat('jS F Y',$this->globals['dueDate']);
            $tokens['value:completed_date'] =globals::dateFormat('jS F Y',$this->globals['completedDate']);
            $tokens['value:status']         =globals::$lang['verification']['status'][$this->globals['status']];

            /** [ METHOD: LOAD TEMPLATE ] */
            $message=$this->loadTemplate('email_verification_complete',array(0=>$tokens));    
               
            /** [ METHOD: EMAIL ] */
            $sent=globals::email($this->globals['to'],$this->globals['from'],globals::EMAIL_FROM_NAME,globals::$lang['email']['verified']['subject'],$message);
            
            /** [ ERROR: EMAIL FAILED TO SEND ] */
            if($sent===false)
                {
                /** [ METHOD: DEBUGGER ] */
                debugger::err('Email verification completed sending failure',__FILE__,__CLASS__,__METHOD__,__LINE__); 
                
                /** [ METHOD: LOG ACTIVITY ] */
                globals::logActivity(globals::$lang['log']['email']['m2'],false);                
                
                /** [ RETURN: BOOLEAN ] */
                unset($file,$tokens,$message,$sent); return(false);
                }
            
            /** [ RETURN: BOOLEAN ] */ 
            unset($file,$tokens,$message); return(true);
            }            
             
        /** [ METHOD: CLIENT VERIFICATION ] */    
        private function clientVerification()
            {
            /** [ OBJECT: WHMCS ] */
            $obj=$this->importClass(1);
            $file=$obj->clientVerification($this->globals['clientID']);
            unset($obj);  

            /** [ ERROR: FILE NOT FOUND ] */
            if($file===false)
                {
                /** [ METHOD: DEBUGGER ] */
                debugger::err('address verification letter request not found for client( '.$this->globals['clientID'].' )',__FILE__,__CLASS__,__METHOD__,__LINE__);
                
                /** [ METHOD: ALERT ] */
                globals::alert(globals::$lang['alert']['verification']['c_m1'],4,false);
                
                /** [ RETURN: BOOLEAN ] */
                unset($file); return(false);
                }
            
            /** [ RETURN: FILE ] */
            return($file);
            }
            
        /** [ METHOD: CLIENT VERIFICATION UPDATE ] */    
        private function clientVerificationUpdate()
            {
            /** [ OBJECT: WHMCS ] */
            $obj=$this->importClass(1);
            $file=$obj->clientVerificationUpdate($this->globals['clientID'],date('Y-m-d'),1,false);
            unset($obj);
            
            /** [ ERROR: UPDATE FAILURE ] */
            if($file===false){unset($file); return(false);}
            
            /** [ RETURN: BOOLEAN ] */
            unset($file); return(true);
            }
            
        /** [ METHOD: LOAD TEMPLATE ] */
        private function loadTemplate($filename,$tokens)
            {
            /** [ OBJECT: TEMPLATES ] */
            $obj=$this->importClass(3);
            $obj->setFileName($filename);
            $obj->setTokens($tokens);
            $xhtml=$obj->getTemplate();
            
            /** [ RETURN: XHTML ] */
            unset($obj); return($xhtml);
            }              
        }
?>