<?php
/**	
 * 
 *	HOOK: ACCEPT ORDER CLASS
 *	Author: Paul Hamlington
 *	Purpose: Wrap the accept order hook code.
 *
 */

    /** [ SET NAMESPACE: MODULIZED DOCSAWAY ] */
    namespace modulized_docsaway;
	

    /** [ HOOK: ACCEPT ORDER CLASS ] */
    final class h_accept_order
        {
	    /** [ PRIVATE CLASS PROPERTIES ] */
	    private $globals;
			
                
	    /** --------------------------> CLASS INTERFACE METHODS <--------------------------*/
		
	
        /** [ METHOD: SET ] */
        public function setOrderID($int){$this->globals['orderID']=$int;}
 
	    /** [ METHOD: EXECUTE ] */
	    public function execute(){$this->executeFunc();}
		
		
	    /** --------------------------> CLASS FUNCTIONALITY METHODS <--------------------------*/
		
				
	    /** [ METHOD: CONSTRUCTOR ] */
	    public function __construct()
            {
            /** [ DEFAULT: GLOBALS ] */
            $this->globals = 
                array('orderID'   => '',
                      'clientID'  => '',
                      'recipient' => array(),
                      'config'    => array(),
                      'reference' => '',
                      'date'      => date('Y-m-d'),
                      'code'      => globals::code(6),                    
                      'trigger'   => false);
            
            /** [ RETURN: BOOLEAN ] */
            return(true);            
            }
                    
        /** [ METHOD: IMPORT CLASS ] */	
        private function importClass($class)
            {
            /** [ CLASS SELECTION ] */
            switch($class)
                {
                /** [ IMPORTED OBJECTS ] */
                case 1: return(new whmcs());
                case 2: return(new docsaway());
                case 4: return(new pdf_verification());
                }
            }	
       
        /** [ METHOD: EXECUTE ] */		
	    private function executeFunc()
            {
            /** [ ERROR: ORDER ID NOT SET ] */
            if(empty($this->globals['orderID']))
                {             
                /** [ METHOD: DEBUGGER ] */
                debugger::err('order id property not set',__FILE__,__CLASS__,__METHOD__,__LINE__); 
                
                /** [ METHOD: LOG ACTIVITY ] */
                globals::logActivity(globals::$lang['log']['verification']['m0'],false);
                
                /** [ RETURN: BOOLEAN ] */
                return(false);
                }
            
            /** [ METHOD: CONFIGURATION FILE ] */
            if($this->configFile()===false){return(false);}
                        
            /** [ METHOD: ORDER ] */
            if($this->order()==false){return(false);}
            
            /** [ METHOD: CLIENT VERIFICATION ] */
            if($this->clientVerification()===true){return(true);}
            
            /** [ METHOD: RECIPIENT DETAILS ] */
            if($this->recipientDetails()==false){return(false);}
            
            /** [ METHOD: HOSTING ] */
            $this->hosting();            
            
            /** [ METHOD: DOMAINS ] */
            $this->domains();
            
            /** [ METHOD: ADD CLIENT VERIFICATION ] */
            if($this->addClientVerification()===false){return(false);}             
            
            /** [ METHOD: MAIL ] */
            if($this->mail()===false){return(false);}

            /** [ METHOD: UPDATE CLIENT VERIFICATION ] */
            if($this->updateClientVerification()===false){return(false);}
            
            /** [ METHOD LOG ACTIVITY ] */    
            globals::logActivity(globals::$lang['log']['verification']['m3'],array('id'=>$this->globals['clientID'],'reference'=>$this->globals['reference']));
            
            /** [ RETURN: BOOLEAN ] */
            return(true);
            }
            
        /** [ METHOD: CONFIG FILE ] */    
        private function configFile()
            {           
            /** [ OBJECT: WHMCS ] */
            $obj=$this->importClass(1);
            $file=$obj->loadSettings('config');
            unset($obj);
             
            /** [ ERROR: FILE NOT FOUND ] */
            if($file===false)
                {
                /** [ METHOD: DEBUGGER ] */
                debugger::err('configuration file not found',__FILE__,__CLASS__,__METHOD__,__LINE__);                 
                
                /** [ METHOD: LOG ACTIVITY ] */
                globals::logActivity(globals::$lang['log']['verification']['m0'],false);
                
                /** [ RETURN: BOOLEAN ] */
                unset($file); return(false);
                }
            
            /** [ STORE: CONFIGURATIONS ] */
            $this->globals['config']=array('product'=>$file['product'],'domainName'=>$file['domainName']);
            
            /** [ RETURN: BOOLEAN ] */
            unset($file); return(true);
            }               
            
        /** [ METHOD: ORDER ] */    
        private function order()
            {
            /** [ OBJECT: WHMCS ] */
            $obj=$this->importClass(1);
            $file=$obj->getOrder($this->globals['orderID']);
            unset($obj);
            
            /** [ ERROR: FILE EMPTY ] */
            if($file===false)
                {
                /** [ METHOD: DEBUGGER ] */
                debugger::err('order not found',__FILE__,__CLASS__,__METHOD__,__LINE__); 
                
                /** [ METHOD: LOG ACTIVITY ] */
                globals::logActivity(globals::$lang['log']['verification']['m0'],false);
                
                /** [ RETURN: BOOLEAN ] */
                unset($file); return(false);
                }
            
            /** [ STORE: CLIENT ID ] */
            $this->globals['clientID']=globals::clientID($file['userid'],$file['contactid'],'ENCODE:2');
            
            /** [ RETURN: BOOLEAN ] */
            unset($file); return(true);
            }
            
        /** [ METHOD: CLIENT VERIFICATION ] */    
        private function clientVerification()
            {
            /** [ OBJECT: WHMCS ] */
            $obj=$this->importClass(1);
            $file=$obj->clientVerification($this->globals['clientID']);
            unset($obj);
            
            /** [ ERROR: FILE EMPTY ] */
            if($file===false){unset($file); return(false);}
            
            /** [ RETURN: BOOLEAN ] */
            unset($file); return(true);
            }
            
        /** [ METHOD: RECIPIENT DETAILS ] */    
        private function recipientDetails()
            {
            /** [ OBJECT: WHMCS ] */
            $obj = $this->importClass(1);    
            $file=$obj->findDetails($this->globals['clientID']);
            unset($obj);
                   
            /** [ ERROR: FILE NOT FOUND ] */
            if($file===false)
                {
                /** [ METHOD: DEBUGGER ] */
                debugger::err('clientID( '.$this->globals['clientID'].' ) not found',__FILE__,__CLASS__,__METHOD__,__LINE__); 
                
                /** [ METHOD: LOG ACTIVITY ] */
                globals::logActivity(globals::$lang['log']['verification']['m0'],false);
                
                /** [ RETURN: BOOLEAN ] */
                unset($file); return(false);
                }
            
            /** [ STORE: RECIPIENT DETAILS ] */
            $this->globals['recipient']['name']     = html_entity_decode($file['firstname'].' '.$file['lastname']);
            $this->globals['recipient']['company']  = html_entity_decode($file['companyname']);
            $this->globals['recipient']['address1'] = html_entity_decode($file['address1']);
            $this->globals['recipient']['address2'] = html_entity_decode($file['address2']);
            $this->globals['recipient']['city']     = html_entity_decode($file['city']);
            $this->globals['recipient']['state']    = html_entity_decode($file['state']);
            $this->globals['recipient']['postcode'] = html_entity_decode($file['postcode']);
            $this->globals['recipient']['country']  = html_entity_decode($file['countrycode']);      
              
            /** [ RETURN: BOOLEAN ] */ 
            unset($file); return(true);            
            }            
            
        /** [ METHOD: HOSTING ] */     
        private function hosting()
            {
            /** [ OBJECT: WHMCS ] */
            $obj=$this->importClass(1);
            $file=$obj->getHosting($this->globals['orderID']);
            unset($obj);
            
            /** [ ERROR: FILE EMPTY ] */
            if($file===false){unset($file); return(false);}
            
            /** [ ERROR: CONFIGURATION PRODUCTS EMPTY ] */
            if(empty($this->globals['config']['product'])){unset($file); return(false);}
            
            /** [ FLIP: KEYS AND VALUES ] */
            foreach($file as $k => $v){$arr[$v['packageid']]=true;} unset($file);

            /** [ CHECK: PRODUCT NEEDS VERIFYING ] */
            foreach($arr as $k => $v){if(isset($this->globals['config']['product'][$k])){$this->globals['trigger']=true; unset($arr); return(true);}}

            /** [ RETURN: BOOLEAN ] */
            unset($arr); return(false);
            }
            
        /** [ METHOD: DOMAINS ] */     
        private function domains()
            {
            /** [ IGNORE: TRIGGER ACTIVATED ] */
            if($this->globals['trigger']===true){return(true);}

            /** [ OBJECT: WHMCS ] */
            $obj=$this->importClass(1);
            $file=$obj->getDomains($this->globals['orderID']);
            unset($obj);
        
            /** [ ERROR: FILE EMPTY ] */
            if($file===false){unset($file); return(false);}
            
            /** [ ERROR: CONFIGURATION PRODUCTS EMPTY ] */
            if(empty($this->globals['config']['domainName'])){unset($file); return(false);}

            /** [ FLIP: KEYS AND VALUES ] */
            foreach($file as $k => $v){$arr[$this->domainType($v['domain'])]=true;} unset($file);
            
            /** [ CHECK: DOMAIN NAME NEEDS VERIFYING ] */
            foreach($this->globals['config']['domainName'] as $k => $v){if(isset($arr[$v])){$this->globals['trigger']=true; unset($arr); return(true);}}

            /** [ RETURN: BOOLEAN ] */
            unset($arr); return(false);
            }
            
        /** [ METHOD: ADD CLIENT VERIFICATION ] */    
        private function addClientVerification()
            {
            /** [ IGNORE: INSERT NOT REQUIRED ] */
            if($this->globals['trigger']===false){return(false);}
            
            /** [ OBJECT: WHMCS ] */
            $obj=$this->importClass(1);
            $file=$obj->clientVerificationAdd($this->globals['clientID'],$this->globals['recipient']['name'],2,$this->globals['date'],$this->globals['code']);
            unset($obj);

            /** [ ERROR: FILE EMPTY ] */
            if($file===false)
                {
                /** [ METHOD: LOG ACTIVITY ] */
                globals::logActivity(globals::$lang['log']['verification']['m0'].'( client:'.$this->globals['clientID'].' )',false);
                
                /** [ RETURN: BOOLEAN ] */              
                unset($file); return(false);
                }
            
            /** [ RETURN: BOOLEAN ] */
            unset($file); return(true);
            }             
            
        /** [ METHOD: MAIL ] */    
        private function mail()
            {
            /** [ IGNORE: INSERT NOT REQUIRED ] */
            if($this->globals['trigger']===false){return(false);}
            
            /** [ METHOD: PDF ] */
            if(($PDF=$this->PDF())===false){unset($PDF); return(false);}
            
            /** [ OBJECT: MAIL ] */
            $obj = $this->importClass(2);
            $file=$obj->mail($this->globals['recipient'],$PDF,false);
            unset($obj,$PDF);
            
            /** [ ERROR: MAIL NOT SENT ] */
            if($file['status']===false)
                {
                /** [ METHOD: LOG ] */
                switch($file['errno'])
                    {
                    /** [ ERROR: CONNECTION FAILURE ] */
                    case '002': case '003': case '040': globals::logActivity(globals::$lang['log']['verification']['m1'],array('id'=>$this->globals['clientID'],'errno'=>$file['errno'])); break;
                    
                    /** [ ERROR: INSUFFICIENT FUNDS ] */
                    case '032': globals::logActivity(globals::$lang['log']['verification']['m2'],array('id'=>$this->globals['clientID'],'errno'=>$file['errno'])); break;
                    
                    /** [ ERROR: LICENSE FAILURE ] */
                    case 'LC001': globals::logActivity(globals::$lang['log']['license']['m1'],array('description'=>$file['description'],'code'=>$file['code'])); break;
                                    
                    /** [ ERROR: CATCH ALL ] */
                    default: globals::logActivity(globals::$lang['log']['verification']['m4'],array('id'=>$this->globals['clientID'],'errno'=>$file['errno'])); break;
                    }

                /** [ METHOD: DELETE CLIENT VERIFICATION ] */    
                $this->delClientVerification();
                
                /** [ RETURN: BOOLEAN ] */
                unset($file); return(false);
                }
            
            /** [ STORE: REFERENCE ] */    
            $this->globals['reference']=$file['transaction']['reference'];
                
            /** [ RETURN: BOOLEAN ] */
            unset($file); return(true);
            }
            
        /** [ METHOD: UPDATE CLIENT VERIFICATION ] */    
        private function updateClientVerification()
            {
            /** [ IGNORE: INSERT NOT REQUIRED ] */
            if($this->globals['trigger']===false){return(false);}
            
            /** [ OBJECT: WHMCS ] */
            $obj=$this->importClass(1);
            $file=$obj->clientVerificationUpdate($this->globals['clientID'],false,false,$this->globals['reference']);
            unset($obj);
            
            /** [ ERROR: FILE EMPTY ] */
            if($file===false)
                {
                /** [ METHOD: LOG ACTIVITY ] */
                globals::logActivity(globals::$lang['log']['verification']['m5'],array('reference'=>$this->globals['reference']));

                /** [ RETURN: BOOLEAN ] */              
                unset($file); return(false);
                }
            
            /** [ RETURN: BOOLEAN ] */
            unset($file); return(true);
            }
            
        /** [ METHOD: DELETE CLIENT VERIFICATION ] */     
        private function delClientVerification()
            {
            /** [ OBJECT: WHMCS ] */
            $obj=$this->importClass(1);
            $file=$obj->clientVerificationDelete($this->globals['clientID']);
            unset($obj);
            
            /** [ ERROR: FILE EMPTY ] */
            if($file===false)
                {
                /** [ METHOD: LOG ACTIVITY ] */
                globals::logActivity(globals::$lang['log']['verification']['m0'].' ( client:'.$this->globals['clientID'].' )',false);

                /** [ RETURN: BOOLEAN ] */              
                unset($file); return(false);
                }
                
            /** [ RETURN: BOOLEAN ] */    
            unset($file); return(true);
            }            
            
        /** [ METHOD: PDF ] */
        private function PDF()
            {
            /** [ OBJECT: PDF VERIFICATION ] */
            $obj=$this->importClass(4);
            $obj->setRecipient($this->globals['recipient']);
            $obj->setDate($this->globals['date']);
            $obj->setCode($this->globals['code']);
            $obj->execute();
            $pdf=$obj->getPDF();
            unset($obj);
            
            /** [ ERROR: PDF NOT CREATED ] */
            if($pdf===false){unset($pdf); return(false);}
            
            /** [ RETURN: PDF ] */
            return($pdf);
            }
        
        /** [ METHOD: DOMAIN TYPE ] */    
        private function domainType($domain)
            {
            /** [ ERROR: DOMAIN NOT SET ] */
            if(empty($domain)){return($domain);}

            /** [ SPLIT: DOMAIN BY DOTS ] */
            $arr=mb_split('\.',$domain);
            
            /** [ REMOVE: DOMAIN NAME ] */
            unset($arr[0]);
            
            /** [ CONVERT: ARRAY TO STRING ] */
            $arr=implode('.',$arr);
            
            /** [ RETURN: DOMAIN TYPE ] */
            return('.'.$arr);
            }
        }
?>